@@ -1,6 +1,5 @@
 from cement import Controller, ex
 from cement.utils.version import get_version_banner
-import ipdb
 from ..core.version import get_version
 from pprint import pprint as pp
 import os
@@ -40,7 +39,7 @@ class Base(Controller):
         help='AWS Security Groups helper functions',
         arguments=[
             (['action'],{
-                "help" : "One of {update, show}",
+                "help" : "One of {update, show, ls}",
                 "action": "store"
             }),
             (['-n','--name'],{
@@ -58,7 +57,16 @@ class Base(Controller):
             (['-P','--ports'],{
                 "help" : "Which ports should AWS SG set",
                 "action" : "store"
-            })
+            }),
+            (['-m','--messages'],{
+                "help" : "Message to add to SG description, WARNing will not use default ports if used "
+                         "Accepts port:messages pairs separated by commas. E.g. 42:answer to life, 22:memes",
+                "action" : "store"
+            }),
+            (['-i','--id'],{
+                "help" : "ID of the SG to act on from the ls DataFrame",
+                "action" : "store"
+            }),
         ]
     )
     def sg(self):
@@ -70,22 +78,24 @@ class Base(Controller):
         ports = self.app.pargs.__dict__.get('ports') or self.app.pargs.__dict__.get('P')
         if ports: ports = [ int(p) for p in ports.split(',') ]
         else: ports = [22, 8888, 8501, 8889, 5432]
-        # if not isinstance(ports, list): ports = [ports]
 
+        # which messages to assign to which ports
+        messages = self.app.pargs.__dict__.get('messages') or self.app.pargs.__dict__.get('m') or ''
+
+        # if any id is given, use that one
+        sid = self.app.pargs.__dict__.get('id') or self.app.pargs.__dict__.get('i')
+        if sid: sid = int(sid)
 
         if self.app.pargs.action=='show':
-            pp(get_sg(name, profile))
+            pp(get_sg(name, profile, sid = sid))
 
         elif self.app.pargs.action=='update':
-            update_sg_to_ip(sg_name=self.app.pargs.name, profile=profile, ports=ports)
+            update_sg_to_ip(sg_name=self.app.pargs.name, profile=profile, ports=ports, messages=messages)
 
         elif self.app.pargs.action=='ls':
             from ..ext.aws_sg import list_security_groups
             df = list_security_groups()
             print(df)
-            # for sg in df.GroupId.unique():
-            #     print(f"GroupdId: {sg}")
-            #     print(df[df.GroupId==sg])
 
         else:
             raise NotImplementedError('As action, chose one of {update, show}')
@@ -487,7 +497,7 @@ class Base(Controller):
         help='All Github related operations',
         arguments=[
              (['action'],{
-                "help" : "To show one of {forks, contrib, stash}.",
+                "help" : "To show one of {forks, contrib, diff}.",
                 "action" : "store"
             }),
             (['-url'],{
