@@ -19,9 +19,16 @@ def get_public_ip():
     # data = '<html><head><title>Current IP Check</title></head><body>Current IP Address: 65.96.168.198</body></html>\r\n'
     return re.compile(r'Address: (\d+\.\d+\.\d+\.\d+)').search(data).group(1)
 
-def get_sg(sg_name: str, profile: str):
+def get_sg(sg_name: str, profile: str, sid: int):
+    
+    # decide if use security group name or security group id
+    if sid:
+        # get relevant row from security group df
+        sg_name = list_security_groups().iloc[sid-1]['GroupName']
+    else:
+        sg_name = sg_name or 'default'
+    
     import boto3
-    sg_name = sg_name or 'default'
     profile = profile or 'default'
 
     ec2 = boto3.session.Session(profile_name=profile, region_name='eu-west-1').client('ec2')
@@ -39,7 +46,8 @@ def check_if_aux(ip_permissions: list):
         return False
 
 def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
-                    ports=[22, 8888, 8501, 8889, 5432], profile='default'):
+                    ports=[22, 8888, 8501, 8889, 5432], profile='default',
+                    messages=''):
     import boto3
 
     ip = f"{get_public_ip()}/32"
@@ -61,15 +69,19 @@ def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
         print('No permissions to revoke. Skipping.')
         sg_res.revoke_ingress(IpPermissions=permissions_to_revoke)
 
-    descriptions = {
-        22: 'Jakub Aux SSH',
-        80: 'Web',
-        8888: 'Jakub Aux Jupyter',
-        8501: 'Jakub Aux Streamlit',
-        8889: 'Jakub Aux Jupyter2',
-        5432: 'Jakub Aux Postgres'
-    }
-    
+    if messages=='':
+        descriptions = {
+                22: 'Jakub Aux SSH',
+                80: 'Web',
+                8888: 'Jakub Aux Jupyter',
+                8501: 'Jakub Aux Streamlit',
+                8889: 'Jakub Aux Jupyter2',
+                5432: 'Jakub Aux Postgres'
+            }
+    else:
+        items = [ i for i in messages.split(',')]
+        descriptions = { int(k.split(':')[0]):k.split(':')[1] for k in items } 
+        ports = [ int(i.split(':')[0]) for i in items ] 
 
     ip_perms = [ {
         'IpProtocol': 'tcp',
@@ -119,6 +131,3 @@ def list_security_groups():
 
     return viewable_df
 
-
-# construct a DataFrame from df.IpPermissionsEgress dictionary
-# ip_permissions_df = pd.DataFrame.from_dict([x[0] for x in df.IpPermissionsEgress.values])
\ No newline at end of file
